StoreVisitor

Struct StoreVisitor 

#[non_exhaustive]
pub struct StoreVisitor { pub base: PathBuf, pub no_timestamps: bool, pub no_xattrs: bool, pub allowed_client_errors: HashSet<StatusCode>, }
Stores all data so that it can be used as a crate::source::Source later.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
base: PathBuf

the output base

no_timestamps: bool

whether to set the file modification timestamps

no_xattrs: bool

whether to store additional metadata (like the etag) using extended attributes

allowed_client_errors: HashSet<StatusCode>

the clients errors which can be ignored

Implementations

Source

impl StoreVisitor

pub fn new(base: impl Into<PathBuf>) -> Self

pub fn no_timestamps(self, no_timestamps: bool) -> Self

pub fn no_xattrs(self, no_xattrs: bool) -> Self

pub fn allow_client_errors( self, allowed_client_errors: HashSet<StatusCode>, ) -> Self

pub fn allow_client_errors_iter( self, allowed_client_errors: impl IntoIterator<Item = StatusCode>, ) -> Self

Similar to Self::allow_client_errors, but accepting any iterable and removing duplicates in the process.